package net.liftweb.util

/*
 * Copyright 2006-2008 WorldWide Conferencing, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import _root_.org.apache.commons.collections.map.{LRUMap, AbstractLinkedMap}
import _root_.org.apache.commons.collections.map.AbstractLinkedMap.LinkEntry

/**
 * LRU Cache wrapping {@link org.apache.commons.collections.map.LRUMap}
 *
 * @param size the maximum number of Elements allowed in the LRU map
 * @param loadFactor the Load Factor to construct our LRU with.
 */
class LRU[KeyType, ValueType](size: Int, loadFactor: Box[Float]) {
  // Alternate constructor that gives you no load factor.
  def this(size: Int) = this(size, Empty)

  private val map = loadFactor match {
    case Full(lf) => new LRUMap(size, lf)
    case _ => new LRUMap(size)
  }

  def update(k: KeyType, v: ValueType) {
    map.put(k, v)
  }

  def remove(k: KeyType) = map.remove(k)

  def apply(k: KeyType): ValueType = map.get(k).asInstanceOf[ValueType]
  def contains(k: KeyType): Boolean = map.containsKey(k)
}
